@@ -4,12 +4,12 @@
 
 require "mkmf"
 
-if RUBY_PLATFORM =~ /arm64-darwin|aarch64-linux/
-  File.write("Makefile", "install clean: ;")
-else
+if RUBY_PLATFORM.match?(/x86_64|x64/)
   $CFLAGS << " -Wall -O3 -pedantic -std=c99 -mbmi -mbmi2 -march=haswell"
 
   create_makefile "x25519_precomputed"
+else
+  File.write("Makefile", "install clean: ;")
 end
 
 # rubocop:enable Style/GlobalVars
